@@ -42,13 +42,13 @@ class Experiment(CnvrgJob):
                                 data={"commit": project.get_current_commit(), **kwargs, **env_helper.get_origin_job()})
         e = resp.get("experiment")
         exp = Experiment(url_join(project.get_project_name(), e.get("slug")))
-        logger_helper.log_message("{title} is running, monitor live at: {url}".format(title=exp['title'], url=exp.href()))
+        logger_helper.log_message("{title} is running, follow live at: {url}".format(title=exp['title'], url=exp.href()))
         return exp
 
     @staticmethod
     def __run_callable(callable, title=None, project=None, cwd=None, library=None, **kwargs):
         experiment = Experiment.init(title=title, project=project, library=library, **kwargs)
-        exit_status = control_stdout_helper.run_callable(callable, callback=lambda x: experiment.log(x))
+        exit_status = control_stdout_helper.run_callable(callable, callback=lambda x: experiment.log(x), err_callback=lambda x: experiment.log(x, log_type=LOGS_TYPE_ERROR))
         experiment.finish(exit_status=exit_status)
         return experiment
 
@@ -65,7 +65,8 @@ class Experiment(CnvrgJob):
         datasets = datasets or wrap_string_to_list(datasets) or wrap_string_to_list(dataset)
 
         if callable:
-            return Experiment.__run_callable(callable, title=title, project=project, library=library)
+            cmd = "func: {func_name}".format(func_name=callable.__name__)
+            return Experiment.__run_callable(callable, title=title, project=project, library=library, cmd=cmd)
         elif local:
             return Experiment.__run_local(cmd=command, title=title, project=project, cwd=working_directory, library=library)
         else:
